/************************************************************************
 * Licensed Materials - Property of IBM and/or HCL
 * (c) Copyright HCL Technologies Ltd. 2019.  All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *************************************************************************/

let enablementInfo = [];
// return formatted html for table data. dataClass is a td style, header is the
// table header text, and contents is an array of info to populate the table with.
function writeTableData(dataClass, header, contents) {
    var tableData = "\n";
    // header shows as java enabled hence shows only if java enabled
    if (ft_browser.java_needed) {
        tableData = "<tr>\n" + '\t<td class="' + dataClass + '">' + header + "</td>\n" + "</tr>\n" + "<tr>\n" + "\t<td colspan=3>\n" + "\t\t<ul>\n";
    }
    for (let x = 0; x < contents.length; x++) {
        if (contents[x] != undefined) {
            tableData += "\t\t<li>" + contents[x] + "</li>\n";
        }
    }
    tableData += "\t\t</ul>\n" + "\t</td>\n" + "</tr>\n";
    return tableData;
}

function testEnablement(success, failure) {
    if (!ft_browser.supported) {
        document.getElementById("tabbed-page:" + enablementInfoTab).innerHTML = StringTable["info_result"] + StringTable["info_result_unsupported"];
    } else if (ft_browser.name === CHROME) {
        document.addEventListener("ft_chrome_addon_installed", function(event) {
            success();
        });
    } else if (ft_browser.name === FIREFOX) {
        document.addEventListener("ft_firefox_addon_installed", function(event) {
            success();
        });
    } else if (ft_browser.name === TRIDENT) {
        //if it is IE the following will be checked
        try {
            ft_browser.addon_installed = true;
            ft_browser.addon_enabled = true;
            ft_browser.java_needed = true;
            ft_browser.java_enabled = navigator.javaEnabled();
            ft_browser.jvm_version = document.JavaInfo != null && document.JavaInfo.getJVMVersion() ? document.JavaInfo.getJVMVersion() : null;
            ft_browser.jvm_vendor = document.JavaInfo != null && document.JavaInfo.getJVMVendor() ? document.JavaInfo.getJVMVendor() : null;
            ft_browser.bs_loaded = document.FtInfo != null && document.FtInfo.bootstrapLoaded() ? document.FtInfo.bootstrapLoaded() : false;
            ft_browser.ft_loaded = document.FtInfo != null && document.FtInfo.javaTestDomainLoaded() ? document.FtInfo.javaTestDomainLoaded() : false;
            ft_browser.htdi_loaded = document.FtInfo != null && document.FtInfo.htmlDomainLoaded() ? document.FtInfo.htmlDomainLoaded() : false;
            ft_browser.domain_name =
                document.FtInfo != null && document.FtInfo.getHtmlDomainImplementationName(navigator.appName) ? document.FtInfo.getHtmlDomainImplementationName(navigator.appName) : null;
        } catch (e) {
            // State should be appropriate by now
        }

        enablementInfo["javaEnabled"] = navigator.javaEnabled() ? StringTable["Yes"] : StringTable["No"];
        enablementInfo["jvmVersion"] = ft_browser.jvmVersion != null ? ft_browser.jvm_version : StringTable["NA"];
        enablementInfo["jvmVendor"] = ft_browser.jvm_vendor != null ? ft_browser.jvm_vendor : StringTable["NA"];
        enablementInfo["bsLoaded"] = ft_browser.bs_loaded != false ? StringTable["Yes"] : StringTable["No"];
        enablementInfo["ftLoaded"] = ft_browser.ft_loaded != false ? StringTable["Yes"] : StringTable["No"];
        enablementInfo["htdiLoaded"] = ft_browser.htdi_loaded != false ? StringTable["Yes"] : StringTable["No"];
        enablementInfo["domainName"] = ft_browser.domain_name != null ? ft_browser.domain_name : StringTable["NA"];

        if (
            ft_browser.addon_installed === true &&
            ft_browser.addon_enabled === true &&
            ft_browser.java_needed === true &&
            ft_browser.java_enabled === true &&
            ft_browser.jvm_version != null &&
            ft_browser.jvm_vendor != null &&
            ft_browser.bs_loaded == true &&
            ft_browser.ft_loaded == true &&
            ft_browser.htdi_loaded == true &&
            ft_browser.domain_name != null
        ) {
            success();
        } else {
            failure();
        }
    }
}

function javaEnabledInfo() {
    var contents = new Array(1);
    contents[0] = StringTable["details_java_enabled_browser"] + ft_browser.java_enabled;
    var tableData = writeTableData("infoheader", StringTable["details_java_enabled_header"], contents);
    return tableData;
}

function pluginEnablementInfo() {
    var contents;
    if (ft_browser.java_needed) {
        //   Special for IE
        contents = new Array(4);
        contents[0] = StringTable["details_bootstrap_loaded"] + enablementInfo["bsLoaded"];
        contents[1] = StringTable["details_java2tdi_loaded"] + enablementInfo["ftLoaded"];
        contents[2] = StringTable["details_htdi_loaded"] + enablementInfo["htdiLoaded"];
        contents[3] = StringTable["details_htdi_name"] + enablementInfo["domainName"];
    } else {
        //if any other browser
        contents = new Array(1);
        contents[0] = "<i>" + StringTable["FF_enablement_extn_status"] + " = </i>" + ft_browser.addon_enabled;
    }
    var tableData = writeTableData("infoheader", StringTable["details_enablement_header"], contents);
    return tableData;
}

function jvmInfo() {
    var contents = new Array(2);
    contents[0] = StringTable["details_jvm_version"] + enablementInfo["jvmVersion"];
    contents[1] = StringTable["details_jvm_vendor"] + enablementInfo["jvmVendor"];
    var tableData = writeTableData("infoheader", StringTable["details_jvm_header"], contents);
    return tableData;
}

function activateTab(i) {
    if (ft_browser.name === TRIDENT) {
        document.getElementById("tab-item:" + i).className = "active";
    } else {
        document.getElementById("tab-item:" + i).classList.add("active");
    }
    if (document.getElementById("tabbed-page:" + i) !== null) {
        document.getElementById("tabbed-page:" + i).style.display = "block";
    }
}
function deactivateTab(i) {
    if (document.getElementById("tab-item:" + i) != null) {
        if (ft_browser.name === TRIDENT) {
            document.getElementById("tab-item:" + i).className = "";
        } else {
            document.getElementById("tab-item:" + i).classList.remove("active");
        }
    }

    if (document.getElementById("tabbed-page:" + i) !== null) {
        document.getElementById("tabbed-page:" + i).style.display = "none";
    }
}

function clickTab(i) {
    for (let j = 0; j < tabCount; ++j) {
        if (j == i) {
            activateTab(j);
        } else {
            deactivateTab(j);
        }
    }
}

function fillInfoContent(status) {
    var dhtml = "<p>";
    dhtml += '<div id="info_result_status">';
    dhtml += StringTable["info_result"];
    if (status) {
        dhtml += StringTable["info_result_passed_1"];
        dhtml += StringTable["info_result_close"];
        dhtml += StringTable["info_result_passed_2"];
        if (ft_browser.name === TRIDENT) {
            dhtml += StringTable["info_result_ie_addon"];
        }
    } else {
        dhtml += StringTable["info_result_failed_1"];
        dhtml += StringTable["info_result_close"];
        if (ft_browser.java_needed) {
            if (!ft_browser.java_enabled) {
                dhtml += StringTable["info_result_failed_javaenabled"];
            }
            if (!ft_browser.ft_loaded || !ft_browser.bs_loaded) {
                dhtml += StringTable["info_result_failed_ft"];
            }
            if (!ft_browser.htdi_loaded) {
                dhtml += StringTable["info_result_failed_htdi"];
            }
        }
        dhtml += StringTable["info_result_failed_2"];
    }
    dhtml += "</p>";
    document.getElementById("tabbed-page:" + enablementInfoTab).innerHTML = dhtml;
}

function fillProblemsContent(status) {
    var dhtml = "<p>";
    if (status) {
        dhtml += StringTable["problem_noproblem"];
    } else {
        if (ft_browser.name == TRIDENT) {
            dhtml += "<table border=1>\n";
        }
        var contents = [];
        if (!ft_browser.java_enabled) {
            if (ft_browser.name === CHROME) {
                contents = new Array(1);
                contents[0] = StringTable["Chrome_enablement_extn_troubleshoot"];
            } else if (ft_browser.name === FIREFOX) {
                contents = new Array(1);
                contents[0] = StringTable["FF_enablement_troubleshoot"];
            } else if (ft_browser.java_needed) {
                contents = new Array(2);
                contents[0] = StringTable["problem_javaenabled_content1"];
                contents[1] = StringTable["problem_javaenabled_content2"];
            }
            dhtml += writeTableData("problemheader", StringTable["problem_javaenabled_header"], contents);
        } else {
            if (!(ft_browser.addon_installed && ft_browser.addon_enabled)) {
                contents = new Array(2);
                contents[0] = StringTable["IE_enablement_extn_troubleshoot"];
                contents[1] = StringTable["IE_allow_activeX"];
                dhtml += writeTableData("problemheader", StringTable["problem_noplugin_header"], contents);
            }
            if (ft_browser.jvm_version == null || ft_browser.jvm_vendor == null) {
                contents = new Array(2);
                contents[0] = StringTable["problem_nojava_content1"];
                contents[1] = StringTable["problem_nojava_content2"];
                dhtml += writeTableData("problemheader", StringTable["problem_nojava_header"], contents);
            }
            if (!(ft_browser.bs_loaded && ft_browser.ft_loaded)) {
                contents = new Array(2);
                contents[0] = StringTable["problem_ft_content1"];
                contents[1] = StringTable["problem_ft_content2"];
                //contents[2] = StringTable["problem_ft_content3"];
                dhtml += writeTableData("problemheader", StringTable["problem_ft_header"], contents);
            }
            if (!ft_browser.htdi_loaded) {
                contents = new Array(2);
                contents[0] = StringTable["problem_htdi_content1"];
                contents[1] = StringTable["problem_htdi_content2"];
                dhtml += writeTableData("problemheader", StringTable["problem_htdi_header"], contents);
            }
        }
        if (ft_browser.name === TRIDENT) {
            dhtml += "</table>\n";
        }
        dhtml += "</p>";
    }
    document.getElementById("tabbed-page:" + enablementProblemsTab).innerHTML = dhtml;
}

function fillDetailsContent(status) {
    var dhtml = "";
    if (ft_browser.java_needed) {
        dhtml += "<p>";
        dhtml += "<table border=1>";
        dhtml += javaEnabledInfo();
        dhtml += pluginEnablementInfo();
        dhtml += "</table>";
        dhtml += "</p>";
    }
    document.getElementById("tabbed-page:" + enablementDetailsTab).innerHTML = dhtml;
}

function fillFlexContent(status) {
    if (ft_browser.java_needed) {
        var dhtml = "<table border=1>";
        dhtml += StringTable["flex_test_general_info"];

        var testbrowsers = new Array(1);
        testbrowsers[0] = StringTable["flex_test_browser_info"];
        dhtml += writeTableData("infoheader", StringTable["flex_test_browser_header"], testbrowsers);

        var contents1 = new Array(1);
        contents1[0] = StringTable["flex_test_compiletime_info"];
        dhtml += writeTableData("infoheader", StringTable["flex_test_compiletime_header"] + " (" + StringTable["flex_test_compiletime_header_ex1"] + ")", contents1);

        var contents = new Array(1);
        contents[0] = StringTable["flex_test_ie_info"];
        dhtml += writeTableData("infoheader", StringTable["flex_test_ie_header"] + " (" + StringTable["flex_test_ie_header_ex1"] + ")", contents);
        /*
        var ff_config = new Array(1);
        ff_config[0] = StringTable["flex_test_ff_info"];
        dhtml += writeTableData("infoheader", StringTable["flex_test_ff_header"] + " (" + StringTable["flex_test_ff_header_ex1"] + ")", ff_config);
*/
        dhtml += "</table>\n";
        document.getElementById("tabbed-page:" + enablementFlexTab).innerHTML = dhtml;
    }
}

function fillContent() {
    testEnablement(
        function() {
            ft_browser.addon_installed = true;
            ft_browser.addon_enabled = true;
            fill_all(true);
        },
        function() {
            if (!ft_browser.addon_installed) {
                fill_all(false);
            }
        }
    );
}

function fill_all(flag) {
    fillInfoContent(flag);
    fillProblemsContent(flag);
    fillDetailsContent(flag);
    fillFlexContent(flag);
    clickTab(0);
}

function setupTabs() {
    if (ft_browser.name === TRIDENT) {
        if (!ft_browser.supported) {
            // Hide all tabs except the results
            document.getElementById("tab-item:" + enablementInfoTab).setAttribute("style", 'display = "block"');
            document.getElementById("tab-item:" + enablementProblemsTab).setAttribute("style", 'display = "none"');
            document.getElementById("tab-item:" + enablementDetailsTab).setAttribute("style", 'display = "none"');
            document.getElementById("tab-item:" + enablementFlexTab).setAttribute("style", 'display = "none"');
        } else {
            // All good. regularly supported browser
            document.getElementById("tab-item:" + enablementInfoTab).setAttribute("style", 'display = "block"');
            document.getElementById("tab-item:" + enablementProblemsTab).setAttribute("style", 'display = "block"');
            document.getElementById("tab-item:" + enablementDetailsTab).setAttribute("style", 'display = "block"');
            document.getElementById("tab-item:" + enablementFlexTab).setAttribute("style", 'display = "block"');
        }
    } else {
        if (!ft_browser.supported) {
            // Hide all tabs except the results
            document.getElementById("tab-item:" + enablementInfoTab).style.display = "block";
            document.getElementById("tab-item:" + enablementProblemsTab).style.display = "none";
            document.getElementById("tab-item:" + enablementDetailsTab).style.display = "none";
            document.getElementById("tab-item:" + enablementFlexTab).style.display = "none";
        } else {
            // All good. regularly supported browser
            document.getElementById("tab-item:" + enablementInfoTab).style.display = "block";
            document.getElementById("tab-item:" + enablementProblemsTab).style.display = "block";
            document.getElementById("tab-item:" + enablementDetailsTab).style.display = "none";
            document.getElementById("tab-item:" + enablementFlexTab).style.display = "none";
            document.getElementById("tabbed-page:" + enablementInfoTab).innerHTML = "<p>" + StringTable["info_result_running"] + "</p>";
        }
    }
}

function load() {
    // Initialize the variables
    initialize();
    // Setup the tabs that should be disaplyed for this type of browser
    setupTabs();
    // Test for enablement, setup the listerners
    testEnablement(
        function() {
            ft_browser.addon_installed = true;
            ft_browser.addon_enabled = true;
            fill_all(true);
        },
        function() {
            // only called by IE when the test fails
            fill_all(false);
        }
    );

    // If its IE, then we already know
    // If not, then thro a message to the content script to communicate with it
    if (ft_browser.name != TRIDENT) {
        setTimeout(function() {
            document.dispatchEvent(new CustomEvent("ft_addon_hello", { detail: "" }));
            check();
        }, 1);
    }
}

var counter = 0;
function check() {
    setTimeout(function() {
        // Check if the content script responded back; if not, then there is no addon installed & enabled
        console.log("Recheck#: " + counter + ": " + new Date().getSeconds() + " " + new Date().getMilliseconds());
        if (!ft_browser.addon_installed) {
            if (counter < 5) {
                counter++;
                document.dispatchEvent(new CustomEvent("ft_addon_hello", { detail: "" }));
                check();
            } else {
                fill_all(false);
            }
        }
    }, 1000);
}
